==> vue-tree-select-2.22.1.tgz: package/lib/index.js <==
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/tree-select/vue';
import Tree from '@opentinyvue/vue-tree';
import BaseSelect from '@opentinyvue/vue-base-select';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "TreeSelect",
  components: {
    TinyTree: Tree,
    TinyBaseSelect: BaseSelect
  },
  props: {
    clearable: Boolean,
    filterable: Boolean,
    filterMethod: Function,
    modelValue: {},
    multiple: Boolean,
    textField: {
      type: String,
      default: "label"
    },
    treeOp: {
      type: Object,
      default: function _default() {
        return {};
      }
    },
    valueField: {
      type: String,
      default: "value"
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("tiny-base-select", {
    ref: "baseSelectRef",
    staticClass: "tiny-tree-select",
    attrs: {
      "clearable": _vm.clearable,
      "filterable": _vm.filterable,
      "filter-method": _vm.filter,
      "multiple": _vm.multiple
    },
    scopedSlots: _vm._u([{
      key: "panel",
      fn: function fn() {
        return [_c("tiny-tree", _vm._b({
          ref: "treeRef",
          attrs: {
            "current-node-key": !_vm.multiple ? _vm.state.currentKey : "",
            "data": _vm.state.treeData,
            "default-checked-keys": _vm.multiple ? _vm.state.defaultCheckedKeys : _vm.treeOp.defaultCheckedKeys || [],
            "default-expand-all": true,
            "expand-on-click-node": false,
            "filter-node-method": _vm.filterMethod,
            "icon-trigger-click-node": false,
            "node-key": _vm.valueField,
            "props": {
              label: _vm.textField
            },
            "show-checkbox": _vm.multiple
          },
          on: {
            "check": _vm.check,
            "node-click": _vm.nodeClick
          }
        }, "tiny-tree", _vm.treeOp, false))];
      },
      proxy: true
    }]),
    model: {
      value: _vm.state.value,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "value", $$v);
      },
      expression: "state.value"
    }
  });
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var TreeSelect = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.undefined";
TreeSelect.install = function(Vue) {
  Vue.component(TreeSelect.name, TreeSelect);
};
TreeSelect.version = version;

export { TreeSelect as default };

==> vue-tree-select-2.23.0.tgz: package/lib/index.js <==
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/tree-select/vue';
import Tree from '@opentinyvue/vue-tree';
import BaseSelect from '@opentinyvue/vue-base-select';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "TreeSelect",
  components: {
    TinyTree: Tree,
    TinyBaseSelect: BaseSelect
  },
  props: {
    clearable: Boolean,
    filterable: Boolean,
    filterMethod: Function,
    modelValue: {},
    multiple: Boolean,
    textField: {
      type: String,
      default: "label"
    },
    treeOp: {
      type: Object,
      default: function _default() {
        return {};
      }
    },
    valueField: {
      type: String,
      default: "value"
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("tiny-base-select", {
    ref: "baseSelectRef",
    staticClass: "tiny-tree-select",
    attrs: {
      "clearable": _vm.clearable,
      "filterable": _vm.filterable,
      "filter-method": _vm.filter,
      "multiple": _vm.multiple
    },
    scopedSlots: _vm._u([{
      key: "panel",
      fn: function fn() {
        return [_c("tiny-tree", _vm._b({
          ref: "treeRef",
          attrs: {
            "check-strictly": _vm.treeOp.checkStrictly,
            "current-node-key": !_vm.multiple ? _vm.state.currentKey : "",
            "data": _vm.state.treeData,
            "default-checked-keys": _vm.multiple ? _vm.state.defaultCheckedKeys : _vm.treeOp.defaultCheckedKeys || [],
            "default-expand-all": true,
            "expand-on-click-node": false,
            "filter-node-method": _vm.filterMethod,
            "icon-trigger-click-node": false,
            "node-key": _vm.valueField,
            "props": {
              label: _vm.textField
            },
            "show-checkbox": _vm.multiple
          },
          on: {
            "check": _vm.check,
            "node-click": _vm.nodeClick
          }
        }, "tiny-tree", _vm.treeOp, false))];
      },
      proxy: true
    }]),
    model: {
      value: _vm.state.modelValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "modelValue", $$v);
      },
      expression: "state.modelValue"
    }
  });
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var TreeSelect = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.23.0";
TreeSelect.install = function(Vue) {
  Vue.component(TreeSelect.name, TreeSelect);
};
TreeSelect.version = version;

export { TreeSelect as default };
